@@ -18,9 +18,8 @@ class FileHandlers:
                 else:
                     self.make_directories()
             except (PermissionError, FileNotFoundError, KeyError) as e:
-                print((e))
                 print("Run with sudo first time to set permissions")
-                sys.exit(1)
+                raise e
         self.sys_log = self.initialize_loggers()
 
     @staticmethod
@@ -56,7 +55,6 @@ class FileHandlers:
 
     def initialize_loggers(self):
         sys_log = logging.getLogger("Domains API")
-        # own_log = logging.getLogger(__name__)
         if self.log_level == "debug":
             level = logging.DEBUG
         elif self.log_level == "warning":
@@ -64,35 +62,30 @@ class FileHandlers:
         else:
             level = logging.INFO
         sys_log.setLevel(level)
-        # own_log.setLevel(level)
         fh = logging.FileHandler(self.log_file)
         sh = logging.StreamHandler(sys.stdout)
         formatter = logging.Formatter(
-            "[%(asctime)s][%(levelname)s][%(name)s] %(message)s",
+            "[%(name)s][%(asctime)s][%(levelname)s] %(message)s",
             datefmt="%Y-%m-%d %H:%M:%S",
         )
         sh_formatter = logging.Formatter(
-            "[%(name)s][%(levelname)s][%(asctime)s] %(message)s",
+            "[%(name)s][%(asctime)s][%(levelname)s] %(message)s",
             datefmt="%Y-%m-%d %H:%M:%S",
         )
         fh.setFormatter(formatter)
         sh.setFormatter(sh_formatter)
         sys_log.addHandler(sh)
         sys_log.addHandler(fh)
-        # own_log.addHandler(fh)
         sys_log.debug("Loggers initialized")
-        return sys_log  # ,  own_log
+        return sys_log
 
     def log(self, msg, level="info"):
         if level == "info":
             self.sys_log.info(msg)
-            # self.own_log.info(msg)
         elif level == "debug":
             self.sys_log.debug(msg)
-            # self.own_log.debug(msg)
         elif level == "warning":
             self.sys_log.warning(msg)
-            # self.own_log.warning(msg)
 
     def set_log_level(self, level="info"):
         self.log_level = level
